@@ -80,6 +80,8 @@ pub struct AquaPackage {
     overrides: Vec<AquaOverride>,
     version_constraint: String,
     version_overrides: Vec<AquaPackage>,
+    pub no_asset: bool,
+    pub error_message: Option<String>,
 }
 
 #[derive(Debug, Deserialize, Clone)]
@@ -135,6 +137,7 @@ pub struct AquaCosign {
     pub signature: Option<AquaCosignSignature>,
     pub key: Option<AquaCosignSignature>,
     pub certificate: Option<AquaCosignSignature>,
+    pub bundle: Option<AquaCosignSignature>,
     #[serde(skip_serializing_if = "Vec::is_empty", default)]
     opts: Vec<String>,
 }
@@ -582,6 +585,12 @@ fn apply_override(mut orig: AquaPackage, avo: &AquaPackage) -> AquaPackage {
         minisign.merge(avo_minisign);
         orig.minisign = Some(minisign);
     }
+    if avo.no_asset {
+        orig.no_asset = true;
+    }
+    if let Some(error_message) = avo.error_message.clone() {
+        orig.error_message = Some(error_message);
+    }
     orig
 }
 
@@ -680,6 +689,12 @@ impl AquaCosign {
             }
             self.certificate.as_mut().unwrap().merge(certificate);
         }
+        if let Some(bundle) = other.bundle.clone() {
+            if self.bundle.is_none() {
+                self.bundle = Some(bundle.clone());
+            }
+            self.bundle.as_mut().unwrap().merge(bundle);
+        }
         if !other.opts.is_empty() {
             self.opts = other.opts.clone();
         }
@@ -842,6 +857,8 @@ impl Default for AquaPackage {
             overrides: vec![],
             version_constraint: "".to_string(),
             version_overrides: vec![],
+            no_asset: false,
+            error_message: None,
         }
     }
 }
