@@ -11,7 +11,7 @@ use eyre::{Result, eyre};
 use crate::cli::args::ToolArg;
 #[cfg(any(test, windows))]
 use crate::cmd;
-use crate::config::{Config, SETTINGS};
+use crate::config::{Config, Settings};
 use crate::env;
 use crate::toolset::{InstallOptions, ToolsetBuilder};
 
@@ -53,8 +53,8 @@ pub struct Exec {
 
 impl Exec {
     #[async_backtrace::framed]
-    pub async fn run(self) -> Result<()> {
-        let config = Config::get().await;
+    pub async fn run(self) -> eyre::Result<()> {
+        let mut config = Config::get().await?;
         let mut ts = measure!("toolset", {
             ToolsetBuilder::new()
                 .with_args(&self.tool)
@@ -70,14 +70,14 @@ impl Exec {
             // also don't autoinstall if at least 1 tool is specified
             // in that case the user probably just wants that one tool
             missing_args_only: !self.tool.is_empty()
-                || !SETTINGS.exec_auto_install
+                || !Settings::get().exec_auto_install
                 || !console::user_attended_stderr()
                 || *env::__MISE_SHIM,
             resolve_options: Default::default(),
             ..Default::default()
         };
         measure!("install_arg_versions", {
-            ts.install_missing_versions(&config, &opts).await?
+            ts.install_missing_versions(&mut config, &opts).await?
         });
         measure!("notify_if_versions_missing", {
             ts.notify_if_versions_missing(&config).await;
