@@ -566,8 +566,8 @@ impl Toolset {
             env.insert(PATH_KEY.to_string(), add_paths);
         }
         env.extend(config.env().await?.clone());
-        if let Some(venv) = uv::uv_venv(config).await {
-            for (k, v) in venv.env {
+        if let Some(venv) = uv::uv_venv(config, self).await {
+            for (k, v) in venv.env.clone() {
                 env.insert(k, v);
             }
         }
@@ -621,8 +621,8 @@ impl Toolset {
         for p in config.path_dirs().await?.clone() {
             paths.insert(p);
         }
-        if let Some(venv) = uv::uv_venv(config).await {
-            paths.insert(venv.venv_path);
+        if let Some(venv) = uv::uv_venv(config, self).await {
+            paths.insert(venv.venv_path.clone());
         }
         if let Some(path) = self.env(config).await?.get(&*PATH_KEY) {
             paths.insert(PathBuf::from(path));
